@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-18'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.023'; # VERSION
+our $VERSION = '0.024'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem file name on a Unix system',
@@ -49,7 +49,7 @@ Sah::Schema::filename::unix - Filesystem file name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.023 of Sah::Schema::filename::unix (from Perl distribution Sah-Schemas-Path), released on 2023-11-18.
+This document describes version 0.024 of Sah::Schema::filename::unix (from Perl distribution Sah-Schemas-Path), released on 2023-11-18.
 
 =head1 SYNOPSIS
 
@@ -83,7 +83,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo/bar";
+ $data = "foo";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -98,8 +98,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo/bar";
- my $res = $validator->($data); # => ["","foo/bar"]
+ $data = "foo";
+ my $res = $validator->($data); # => ["","foo"]
  
  # a sample invalid data
  $data = "foo\0";
