@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-18'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.023'; # VERSION
+our $VERSION = '0.024'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to filesystem path
@@ -22,7 +22,7 @@ Sah::Schemas::Path - Schemas related to filesystem path
 
 =head1 VERSION
 
-This document describes version 0.023 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-11-18.
+This document describes version 0.024 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-11-18.
 
 =head1 DESCRIPTION
 
@@ -94,6 +94,20 @@ C<delete-files-in> script). It is safer to use this schema when performing a
 non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 
+=item * L<dirname::default_only_subdir_in_curdir|Sah::Schema::dirname::default_only_subdir_in_curdir>
+
+Directory name, defaults to only subdirectory in current directory (if there is one).
+
+This is like the C<dirname> schema but with a default value of "only subdirectory
+in the current directory". That is, if the current directory has a single
+subdirectory and nothing else.
+
+Note: be careful when using this schema for actions that are destructive,
+because a user can perform those actions without giving an argument (e.g. in a
+C<delete-files-in> script). It is safer to use this schema when performing a
+non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+
+
 =item * L<dirname::exists|Sah::Schema::dirname::exists>
 
 Directory name, must exist on filesystem.
@@ -102,6 +116,20 @@ This is like the C<dirname> schema but with an extra check that the path must
 already exist.
 
 
+=item * L<dirname::exists::default_only_subdir_in_curdir|Sah::Schema::dirname::exists::default_only_subdir_in_curdir>
+
+Directory name, must exist on the filesystem, defaults to only subdirectory in current directory (if there is one).
+
+This is like the C<dirname::exists> schema but with a default value of "only
+subdirectory in the current directory". That is, if the current directory has a
+single subdirectory and nothing else.
+
+Note: be careful when using this schema for actions that are destructive,
+because a user can perform those actions without giving an argument (e.g. in a
+C<delete-files-in> script). It is safer to use this schema when performing a
+non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+
+
 =item * L<dirname::not_exists|Sah::Schema::dirname::not_exists>
 
 Directory name, must not exist on filesystem.
@@ -167,6 +195,21 @@ What's the difference between this schema and C<dirname>? The default completion
 rule. C<dirname>'s completion only includes directories and not files.
 
 
+=item * L<filename::default_only_file_in_curdir|Sah::Schema::filename::default_only_file_in_curdir>
+
+File name, defaults to only file in current directory (if there is one).
+
+This is like the C<filename> schema but with a default value of "only file in the
+current directory". That is, if the current directory has a single plain file
+and nothing else.
+
+Note: be careful when using this schema for actions that are destructive,
+because a user can perform those actions without giving an argument (e.g. in a
+C<delete-file> script). It is safer to use this schema when performing a
+non=destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
+default.
+
+
 =item * L<filename::exists|Sah::Schema::filename::exists>
 
 File name, must exist on filesystem.
@@ -175,6 +218,21 @@ This is like the C<filename> schema but with an extra check that the path must
 already exist.
 
 
+=item * L<filename::exists::default_only_file_in_curdir|Sah::Schema::filename::exists::default_only_file_in_curdir>
+
+File name, must exist on the filesystem, defaults to only file in current directory (if there is one).
+
+This is like the C<filename::exists> schema but with a default value of "only
+file in the current directory". That is, if the current directory has a single
+plain file and nothing else.
+
+Note: be careful when using this schema for actions that are destructive,
+because a user can perform those actions without giving an argument (e.g. in a
+C<delete-file> script). It is safer to use this schema when performing a
+non=destructive action (e.g. C<checksum>) and/or operate in dry-run mode by
+default.
+
+
 =item * L<filename::not_exists|Sah::Schema::filename::not_exists>
 
 File name, must not already exist on filesystem.
